pub struct DataAgentService { /* private fields */ }Expand description
Implements a client for the Data Analytics API with Gemini.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
project_id: &str,
location_id: &str,
) -> anyhow::Result<()> {
let client = DataAgentService::builder().build().await?;
let mut list = client.list_data_agents()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Service Description
Service describing handlers for resources.
Configuration
To configure DataAgentService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://geminidataanalytics.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
DataAgentService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap DataAgentService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl DataAgentService
impl DataAgentService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for DataAgentService.
let client = DataAgentService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: DataAgentService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: DataAgentService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn list_data_agents(&self) -> ListDataAgents
pub fn list_data_agents(&self) -> ListDataAgents
Lists DataAgents in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService, project_id: &str, location_id: &str
) -> Result<()> {
let mut list = client.list_data_agents()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn list_accessible_data_agents(&self) -> ListAccessibleDataAgents
pub fn list_accessible_data_agents(&self) -> ListAccessibleDataAgents
Lists DataAgents that are accessible to the caller in a given project and location.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService, project_id: &str, location_id: &str
) -> Result<()> {
let mut list = client.list_accessible_data_agents()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_data_agent(&self) -> GetDataAgent
pub fn get_data_agent(&self) -> GetDataAgent
Gets details of a single DataAgent.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService, project_id: &str, location_id: &str, data_agent_id: &str
) -> Result<()> {
let response = client.get_data_agent()
.set_name(format!("projects/{project_id}/locations/{location_id}/dataAgents/{data_agent_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_data_agent(&self) -> CreateDataAgent
pub fn create_data_agent(&self) -> CreateDataAgent
Creates a new DataAgent in a given project and location.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_geminidataanalytics_v1::model::DataAgent;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService, project_id: &str, location_id: &str
) -> Result<()> {
let response = client.create_data_agent()
.set_parent(format!("projects/{project_id}/locations/{location_id}"))
.set_data_agent(
DataAgent::new()/* set fields */
)
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn create_data_agent_sync(&self) -> CreateDataAgentSync
pub fn create_data_agent_sync(&self) -> CreateDataAgentSync
Creates a new DataAgent in a given project and location synchronously.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let response = client.create_data_agent_sync()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_data_agent(&self) -> UpdateDataAgent
pub fn update_data_agent(&self) -> UpdateDataAgent
Updates the parameters of a single DataAgent.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_geminidataanalytics_v1::model::DataAgent;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService, project_id: &str, location_id: &str, data_agent_id: &str
) -> Result<()> {
let response = client.update_data_agent()
.set_data_agent(
DataAgent::new().set_name(format!("projects/{project_id}/locations/{location_id}/dataAgents/{data_agent_id}"))/* set fields */
)
.set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
.poller().until_done().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn update_data_agent_sync(&self) -> UpdateDataAgentSync
pub fn update_data_agent_sync(&self) -> UpdateDataAgentSync
Updates the parameters of a single DataAgent synchronously.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let response = client.update_data_agent_sync()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_data_agent(&self) -> DeleteDataAgent
pub fn delete_data_agent(&self) -> DeleteDataAgent
Deletes a single DataAgent.
Long running operations
This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.
Example
use google_cloud_lro::Poller;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService, project_id: &str, location_id: &str, data_agent_id: &str
) -> Result<()> {
client.delete_data_agent()
.set_name(format!("projects/{project_id}/locations/{location_id}/dataAgents/{data_agent_id}"))
.poller().until_done().await?;
Ok(())
}Sourcepub fn delete_data_agent_sync(&self) -> DeleteDataAgentSync
pub fn delete_data_agent_sync(&self) -> DeleteDataAgentSync
Deletes a single DataAgent synchronously.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
client.delete_data_agent_sync()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn get_iam_policy(&self) -> GetIamPolicy
pub fn get_iam_policy(&self) -> GetIamPolicy
Gets the IAM policy for DataAgent
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let response = client.get_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn set_iam_policy(&self) -> SetIamPolicy
pub fn set_iam_policy(&self) -> SetIamPolicy
Sets the IAM policy for a DataAgent.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let response = client.set_iam_policy()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_locations(&self) -> ListLocations
pub fn list_locations(&self) -> ListLocations
Lists information about the supported locations for this service.
This method lists locations based on the resource scope provided in
the ListLocationsRequest.name field: *
Global locations: If name is empty, the method lists the
public locations available to all projects. * Project-specific
locations: If name follows the format
projects/{project}, the method lists locations visible to that
specific project. This includes public, private, or other
project-specific locations enabled for the project.
For gRPC and client library implementations, the resource name is
passed as the name field. For direct service calls, the resource
name is
incorporated into the request path based on the specific service
implementation and version.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let mut list = client.list_locations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_location(&self) -> GetLocation
pub fn get_location(&self) -> GetLocation
Gets information about a location.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let response = client.get_location()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn list_operations(&self) -> ListOperations
pub fn list_operations(&self) -> ListOperations
Provides the Operations service functionality in this service.
Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let mut list = client.list_operations()
/* set fields */
.by_item();
while let Some(item) = list.next().await.transpose()? {
println!("{:?}", item);
}
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn delete_operation(&self) -> DeleteOperation
pub fn delete_operation(&self) -> DeleteOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
client.delete_operation()
/* set fields */
.send().await?;
Ok(())
}Sourcepub fn cancel_operation(&self) -> CancelOperation
pub fn cancel_operation(&self) -> CancelOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_geminidataanalytics_v1::Result;
async fn sample(
client: &DataAgentService
) -> Result<()> {
client.cancel_operation()
/* set fields */
.send().await?;
Ok(())
}Trait Implementations
Sourceimpl Clone for DataAgentService
impl Clone for DataAgentService
Sourcefn clone(&self) -> DataAgentService
fn clone(&self) -> DataAgentService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for DataAgentService
impl !UnwindSafe for DataAgentService
impl Freeze for DataAgentService
impl Send for DataAgentService
impl Sync for DataAgentService
impl Unpin for DataAgentService
impl UnsafeUnpin for DataAgentService